==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/RepositoryEJB/src/com/clustercontrol/repository/bean/FacilityAttributeConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.bean;

/**
 * Facility(BMP Entity Bean)の属性名定義クラス<BR>
 * 定義されているStringはLDAPの属性を一致します。
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class FacilityAttributeConstant {
	public static final String DN = "dn";
	public static final String FACILITYID = "ccFacilityId";
	public static final String CN = "cn";
	public static final String DESCRIPTION = "description";
	public static final String PINGWATCH = "ccPingWatch";
	public static final String PINGWATCHSTATUS = "ccPingWatchStatus";
	public static final String AGENTWATCH = "ccAgentWatch";
	public static final String AGENTWATCHSTATUS = "ccAgentWatchStatus";
	public static final String STATUSWATCH = "ccStatusWatch";
	public static final String LOGWATCH = "ccLogWatch";
	public static final String AGENTCONTROL = "ccAgentControl";
	public static final String DHCPCLIENT = "ccDhcpClient";
	public static final String IPTYPE = "ccIpType";
	public static final String IPPROTOCOLNUMBER = "ipProtocolNumber";
	public static final String IPNETWORKNUMBER = "ipNetworkNumber";
	public static final String IPNETWORKNUMBERV6 = "ccIpNetworkNumberV6";
	public static final String HOST = "host";
	public static final String MACHINE = "ccMachine";
	public static final String PLATFORM = "ccPlatform";
	public static final String OSNAME = "ccOsName";
	public static final String NODENAME = "ccNodeName";
	public static final String OSRELEASE = "ccOsRelease";
	public static final String OSVERSION = "ccOsVersion";
	public static final String CHARSET = "ccCharSet";
	public static final String MANAGERNAME = "ccManagerName";
	public static final String MANAGERCONTACT = "ccManagerContact";
	public static final String CREATORSNAME = "ccCreatorsName";
	public static final String CREATETIMESTAMP = "ccCreateTimestamp";
	public static final String MODIFIERSNAME = "ccModifiersName";
	public static final String MODIFYTIMESTAMP = "ccModifyTimestamp";
	public static final String SNMPCOMMUNITY = "ccSnmpCommunity";
	public static final String SNMPPORT = "ccSnmpPort";
	public static final String SNMPVERSION ="ccSnmpVersion";
	public static final String SORT_VALUE="ccFacilitySortValue";
}

==> hinemos_src-3.0.3.tar.gz: Hinemos_src-3.0.3/RepositoryEJB/src/com/clustercontrol/repository/bean/FacilityAttributeConstant.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.repository.bean;

/**
 * Facility(BMP Entity Bean)の属性名定義クラス<BR>
 * 定義されているStringはLDAPの属性を一致します。
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class FacilityAttributeConstant {
	public static final String DN = "dn";
	public static final String FACILITYID = "ccFacilityId";
	public static final String CN = "cn";
	public static final String DESCRIPTION = "description";
	public static final String PINGWATCH = "ccPingWatch";
	public static final String PINGWATCHSTATUS = "ccPingWatchStatus";
	public static final String AGENTWATCH = "ccAgentWatch";
	public static final String AGENTWATCHSTATUS = "ccAgentWatchStatus";
	public static final String STATUSWATCH = "ccStatusWatch";
	public static final String LOGWATCH = "ccLogWatch";
	public static final String AGENTCONTROL = "ccAgentControl";
	public static final String DHCPCLIENT = "ccDhcpClient";
	public static final String IPTYPE = "ccIpType";
	public static final String IPPROTOCOLNUMBER = "ipProtocolNumber";
	public static final String IPNETWORKNUMBER = "ipNetworkNumber";
	public static final String IPNETWORKNUMBERV6 = "ccIpNetworkNumberV6";
	public static final String HOST = "host";
	public static final String MACHINE = "ccMachine";
	public static final String PLATFORM = "ccPlatform";
	public static final String OSNAME = "ccOsName";
	public static final String NODENAME = "ccNodeName";
	public static final String OSRELEASE = "ccOsRelease";
	public static final String OSVERSION = "ccOsVersion";
	public static final String CHARSET = "ccCharSet";
	public static final String MANAGERNAME = "ccManagerName";
	public static final String MANAGERCONTACT = "ccManagerContact";
	public static final String CREATORSNAME = "ccCreatorsName";
	public static final String CREATETIMESTAMP = "ccCreateTimestamp";
	public static final String MODIFIERSNAME = "ccModifiersName";
	public static final String MODIFYTIMESTAMP = "ccModifyTimestamp";
	public static final String SNMPCOMMUNITY = "ccSnmpCommunity";
	public static final String SNMPPORT = "ccSnmpPort";
	public static final String SNMPVERSION ="ccSnmpVersion";
	public static final String SORT_VALUE="ccFacilitySortValue";
	public static final String VALID="ccValid";
	public static final String SNMPTIMEOUT = "ccSnmpTimeout"; 
	public static final String SNMPRETRIES= "ccSnmpRetries";
	public static final String SNMPPROXY= "ccSnmpProxy";
	public static final String NOTE= "ccNote";
	public static final String ICONIMAGE= "ccIconImage";
	public static final String VIRTNODETYPE= "ccVirtualizationNodeType";
	public static final String VMMANAGEMENTNODE= "ccVMManagementNode";
	public static final String VMINDEX= "ccVMINDEX";
	public static final String VMNAME= "ccVMName";
	public static final String VIRTSOLUTION= "ccVirtualizationSolution";

	
	
	
}
